FAQ
===

Here are some problems that users have come across often:

- When I remove a folder manually in a library or I synchronize
  the library manually, I do not see the new papers in the library.
  **Answer**: You probably need to update the cache because Papis did not
  know anything about your changes in the library since you did it by yourself.

  .. code::

    papis cache clear

  will do.


For more information you can also check the
`github faq <https://github.com/papis/papis/issues?utf8=%E2%9C%93&q=label:faq>`__ link.
